library(gmailr)
library(Hmisc)
library(dplyr)
library(tidyr)
library(ggplot2)

som <- function(x) {
  as.Date(format(x, "%Y-%m-01"))
}

eom <- function(x) {
  som(som(x) + 35) - 1
}

interhpc <- function(filename){
  start_date <- Sys.Date()-7
  end_date <- Sys.Date()
  gmail_search_query <- paste0("after:", start_date, " before:", end_date, 
                               " from:hpcdb@hpcdb.intersect.org.au",
                               " subject:UTS HPC Usage Report")
  print(gmail_search_query)
  ids <- id(messages(search = gmail_search_query))
  #print(ids)
  #msg <- body(message(ids$messages[[1]]$id))
  msg <- body(message(ids[1]))
  msg <- gsub(" ", "", msg, fixed = TRUE)
  msg <- string.break.line(msg)
  msg <- sub("\r","",msg[[1]][3:(length(msg[[1]])-1)])
  print(msg)
  dataset <- read.table(text=msg,header=TRUE, sep=",")
  write.csv(dataset, file="../reportdata/datafiles/HPC_usage.csv")
  
  #Comparing HPC total merit, adjusted allocation and usage by machine
  hpcsummary <- dataset %>% 
    group_by(machine) %>% 
    dplyr::summarize(merit=sum(merit),adjusted_allocation=sum(total_allocation),total_usage=sum(usage))
  hpcsummary <- gather(hpcsummary,sum_of,CPU_hours,merit:total_usage,factor_key=TRUE)
  outputfilename1 <- "interHPC-CompareMeritUsageByMachine.png"
  png(filename=outputfilename1)
  options(scipen=999)
  ggplot(data=hpcsummary, aes(x=machine, y=CPU_hours, fill=sum_of)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_discrete("")
  ggsave(outputfilename1)
  
  #Comparing HPC total merit, adjusted allocation and usage by quarter
  comparesummary <- dataset %>% 
    group_by(quarter) %>% 
    dplyr::summarize(merit=sum(merit),adjusted_allocation=sum(total_allocation),total_usage=sum(usage))
  comparesummary <- gather(comparesummary,sum_of,CPU_hours,merit:total_usage,factor_key=TRUE)
  outputfilename2 <- "interHPC-CompareMeritUsageByQuarter.png"
  png(filename=outputfilename2)
  options(scipen=999)
  ggplot(data=comparesummary, aes(x=quarter, y=CPU_hours, fill=sum_of)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_discrete("") +
    scale_x_continuous(breaks=c(1,2,3,4))
  ggsave(outputfilename2)
  
  #comparing HPC machine usage by quarter
  quartersummary <- dataset %>% 
    group_by(quarter,machine) %>% 
    dplyr::summarize(CPU_hours=sum(usage))
  outputfilename3 <- "interHPC-CompareMachineByQuarter.png"
  png(filename=outputfilename3)
  options(scipen=999)
  ggplot(data=quartersummary, aes(x=quarter, y=CPU_hours, fill=machine)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_discrete("") +
    scale_x_continuous(breaks=c(1,2,3,4))
  ggsave(outputfilename3)
  
}
