library(dplyr)
library(tidyr)
library(ggplot2)

utshpc <- function(raijinfilename, hpccfilename){
  # Reading Raijin file
  raijindata <- read.csv(file=raijinfilename)
  raijindata <- raijindata[raijindata$Project == "Total",] %>%
    select(c(Project,Institution,Lead.CI,q1.Allocated,q1.Used,q2.Allocated,q2.Used,
                                  q3.Allocated,q3.Used,q4.Allocated,q4.Used))
  raijindata <- raijindata %>% 
    gather(sum_of,CPU_hours,
         c(q1.Allocated,q1.Used,q2.Allocated,q2.Used,q3.Allocated,q3.Used,q4.Allocated,q4.Used),
         factor_key=TRUE) %>% 
    separate(col = sum_of, into = c("quarter", "category"), sep = "\\.")
  raijindata <- data.frame(quarter=gsub('q','',raijindata$quarter),
                           category=raijindata$category,
                           CPU_hours=raijindata$CPU_hours * 1000)
  print(raijindata)
  
  # Reading HPCC file
  hpccdata <- read.csv(file=hpccfilename, sep="|")
  hpccdata$month <- seq.int(nrow(hpccdata))
  hpccsummary <- data.frame(month=hpccdata$month,
                         quarter=as.integer((hpccdata$month-1)/3+1),
                         jobs=hpccdata$jobs,
                         usage=hpccdata$CPU.Time/3600)
  hpccsummary <- gather(hpccsummary,category,CPU_hours,jobs:usage,factor_key=TRUE)
  print(hpccsummary)
  
  #Comparing Raijin allocation and usage by quarter
  outputfilename1 <- "utsNCIRaijin-CompareAllocationUsageByQuarter.png"
  png(filename=outputfilename1)
  options(scipen=999)
  ggplot(data=raijindata, aes(x=quarter, y=CPU_hours, fill=category)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_discrete("")
  ggsave(outputfilename1)
  print("chart 1 generated")
  
  
  # UTS HPCC Jobs and Usage (CPU hours) by Month
  outputfilename2 <- "utsHPCC-CompareByMonth.png"
  png(filename=outputfilename2)
  options(scipen=999)
  ggplot(data=hpccsummary, aes(x=month, y=CPU_hours, fill=category)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_x_continuous(breaks = c(1,2,3,4,5,6,7,8,9,10,11,12))
  ggsave(outputfilename2)
  print("chart 2 generated")
  
  #Comparison summary
  hpccsummary <- hpccsummary[hpccsummary$category=="usage",] %>%
    group_by(quarter) %>%
    dplyr::summarize(CPU_hours=sum(CPU_hours))
  hpccsummary$machine = "HPCC"
  raijinsummary <- raijindata[raijindata$category=="Used",]
  raijinsummary$machine = "Raijin"
  raijinsummary <- raijinsummary[ , !(names(raijinsummary) %in% "category")]
  comparisonsummary <- rbind(hpccsummary,raijinsummary)

  outputfilename3 <- "utsCompareMachinesByQuater.png"
  png(filename=outputfilename3)
  options(scipen=999)
  ggplot(data=comparisonsummary, aes(x=quarter, y=CPU_hours, fill=machine)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_discrete("")
  ggsave(outputfilename3)
  print("chart 3 generated")
  
}